<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>InfoPolylineArea</name>
    <message>
        <location filename="../InfoPolylineArea.js" line="+53"/>
        <source>Choose polyline</source>
        <translation>ポリラインを選択</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Area</source>
        <translation>面積</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Circumference</source>
        <translation>外周</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Polyline area:</source>
        <translation>ポリライン面積:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>circumference:</source>
        <translation>外周:</translation>
    </message>
    <message>
        <location filename="../InfoPolylineAreaInit.js" line="+2"/>
        <source>Polyl&amp;ine Area</source>
        <translation>ポリラインの面積</translation>
    </message>
</context>
</TS>
